@@ -13,8 +13,8 @@
 # limitations under the License.
 
 """This module provides some specific luigi parameters."""
-import re
 import warnings
+from pathlib import Path
 
 import luigi
 
@@ -26,11 +26,11 @@ class OptionalParameterTypeWarning(UserWarning):
 class ExtParameter(luigi.Parameter):
     """Class to parse file extension parameters."""
 
-    def parse(self, x):
-        """Parse the given value to an extension suffix without dot."""
-        pattern = re.compile(r"\.?(.*)")
-        match = re.match(pattern, x)
-        return match.group(1)
+    def normalize(self, x):
+        """Normalize the given value to an extension suffix without dot."""
+        if x.startswith("."):
+            x = x[1:]
+        return x
 
 
 class RatioParameter(luigi.NumericalParameter):
@@ -84,6 +84,34 @@ class BoolParameter(luigi.BoolParameter):
             self.parsing = self.__class__.EXPLICIT_PARSING
 
 
+class PathParameter(luigi.Parameter):
+    """Class to parse file path parameters.
+
+    Args:
+        absolute (bool): the given path is converted to an absolute path.
+        create (bool): a folder is automatically created to the given path.
+        exists (bool): raise a :class:`ValueError` if the path does not exist.
+    """
+
+    def __init__(self, *args, absolute=False, create=False, exists=False, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        self.absolute = absolute
+        self.create = create
+        self.exists = exists
+
+    def normalize(self, x):
+        """Normalize the given value to a :class:`pathlib.Path` object."""
+        path = Path(x)
+        if self.absolute:
+            path = path.absolute()
+        if self.create:
+            path.mkdir(parents=True, exist_ok=True)
+        if self.exists and not path.exists():
+            raise ValueError(f"The path {path} does not exist.")
+        return path
+
+
 class OptionalParameter:
     """Mixin to make a parameter class optional."""
 
@@ -180,3 +208,9 @@ class OptionalTupleParameter(OptionalParameter, luigi.TupleParameter):
     """Class to parse optional tuple parameters."""
 
     expected_type = tuple
+
+
+class OptionalPathParameter(OptionalParameter, PathParameter):
+    """Class to parse optional path parameters."""
+
+    expected_type = str
