@@ -32,7 +32,7 @@ def test_ext_parameter(luigi_tools_working_directory):
     class TaskExtParameter(luigi.Task):
         """"""
 
-        a = luigi_tools.parameter.ExtParameter(default="ext_from_default")
+        a = luigi_tools.parameter.ExtParameter(default=".ext_from_default")
         test_type = luigi.Parameter(default="default")
 
         def run(self):
@@ -541,3 +541,70 @@ class TestBoolParameter:
                 """"""
 
                 a = luigi_tools.parameter.BoolParameter(default=True, parsing="implicit")
+
+
+@pytest.mark.parametrize("default", [None, "not_existing_dir"])
+@pytest.mark.parametrize("absolute", [True, False])
+@pytest.mark.parametrize("create", [True, False])
+@pytest.mark.parametrize("exists", [True, False])
+def test_path_parameter(tmpdir, default, absolute, create, exists):
+    class TaskPathParameter(luigi.Task):
+
+        a = luigi_tools.parameter.PathParameter(
+            default=str(tmpdir / default) if default is not None else str(tmpdir),
+            absolute=absolute,
+            create=create,
+            exists=exists,
+        )
+        b = luigi_tools.parameter.OptionalPathParameter(
+            default=str(tmpdir / default) if default is not None else str(tmpdir),
+            absolute=absolute,
+            create=create,
+            exists=exists,
+        )
+        c = luigi_tools.parameter.OptionalPathParameter(default=None)
+        d = luigi_tools.parameter.OptionalPathParameter(default="not empty default")
+
+        def run(self):
+            # Use the parameter as a Path object
+            new_file = self.a / "test.file"
+            new_optional_file = self.b / "test_optional.file"
+            if default is not None and not create:
+                new_file.parent.mkdir(parents=True)
+            new_file.touch()
+            new_optional_file.touch()
+            assert new_file.exists()
+            assert new_optional_file.exists()
+            assert self.c is None
+            assert self.d is None
+
+        def output(self):
+            return luigi.LocalTarget("not_existing_file")
+
+    # Test with default values
+    with set_luigi_config({"TaskPathParameter": {"d": ""}}):
+        if default is not None and not create and exists:
+            with pytest.raises(ValueError, match="The path .* does not exist"):
+                luigi.build([TaskPathParameter()], local_scheduler=True)
+        else:
+            assert luigi.build([TaskPathParameter()], local_scheduler=True)
+
+    # Test with values from config
+    with set_luigi_config(
+        {
+            "TaskPathParameter": {
+                "a": str(tmpdir / (default + "_from_config"))
+                if default is not None
+                else str(tmpdir),
+                "b": str(tmpdir / (default + "_from_config"))
+                if default is not None
+                else str(tmpdir),
+                "d": "",
+            }
+        }
+    ):
+        if default is not None and not create and exists:
+            with pytest.raises(ValueError, match="The path .* does not exist"):
+                luigi.build([TaskPathParameter()], local_scheduler=True)
+        else:
+            assert luigi.build([TaskPathParameter()], local_scheduler=True)
